# TerraLib

#### 介绍

工作常用lib

#### 包含内容

1. BaseConversion 进制转换，支持二进制，八进制，十进制，十六进制
2. Excel excel 读写,支持xls和xlsx,是对xlrd,xlwt,openpyxl的封装，统一接口
3. Git git 操作，将git操作封装
4. SubProcess 子进程，将subprocess封装
5. Svn svn 操作，将svn操作封装
6. Time 时间操作，支持时间单位的转换

#### 安装教程

pip install TerraLib

#### 使用说明

安装后，可以根据自己的需要导入到自己项目中。
示例： from TerraLib import BaseConversion

#### 参与贡献
